Re: [cmake-developers] FindQt4.cmake Qt5 qmake

2014-06-27 Thread Nils Gladitz

On 25.06.2014 16:07, Nils Gladitz wrote:
Eike pointed out misguided FindQt4.cmake diagnostics in my dashboard 
submissions:

http://open.cdash.org/viewConfigure.php?buildid=3382423

I merged FindQt4-ignore-qt5 for testing which I hope is an 
appropriate fix.


I would appreciate it if those who are more familiar with the module 
could verify that it is actually valid as-is.


I accidentally found out that Clinton already fixed this with 
83934757c942672d8bea79f11e51a184b168a212.

I reverted the topic.

Nils
--

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [cmake-developers] FindJPEG alternative name

2014-06-27 Thread Brad King
On 06/26/2014 03:19 PM, Sebastian Elsner wrote:
 newer version of jpeglib build the .lib file on windows with a different 
 name by default. Its now called libjpeg.lib instead of jpeg.lib. Please 
 see the patch appended.

Applied, thanks:

 FindJPEG: Add alternative name 'libjpeg'
 http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=115811dc

-Brad

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [cmake-developers] [PATCH] FindOpenMP: ICC 15 deprecates -openmp, use -qopenmp

2014-06-27 Thread Brad King
On 06/26/2014 09:29 AM, Adam Strzelecki wrote:
 Intel Composer XE 2015 Beta 2 deprecates all options starting with -o for sake
 of compatibility with other compilers expecting anything goes after -o... is
 output file name.

Applied, thanks:

 FindOpenMP: ICC 15 deprecates -openmp, use -qopenmp
 http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4671f3ab

 +  elseif(${CMAKE_${LANG}_COMPILER_ID} EQUAL Intel AND

I adjusted this line because EQUAL is for numerical comparisons.
I changed it to STREQUAL.

-Brad

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


[cmake-developers] Remove check for source files in add_library()

2014-06-27 Thread Ådne Hovda

Hi

It would be handy when creating macros that wraps add_library where the 
number of source files is unknown to be able to write:


add_library( mylib )
target_sources( mylib PRIVATE mylib.c mylib.h )

but this fails with the warning You have called ADD_LIBRARY for library 
testlib without any source files. This typically indicates a problem 
with your CMakeLists.txt file


I have tried to just remove that check in cmAddLibraryCommand and apart 
from a warning about missing LINKER_LANGUAGE it works okay.


https://github.com/aadnehovda/CMake/commit/d527b1db787c426517f7af357df0cd3ba9d9a12a

I guess there are other implications I have not though of as well?

--
Best regards,
Ådne Hovda

--

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [cmake-developers] FindQt4.cmake Qt5 qmake

2014-06-27 Thread Brad King
On 06/27/2014 05:07 AM, Nils Gladitz wrote:
 It has been pointed out that the change might still make sense since the 
 current behavior just removes the diagnostics in the
 Qt4_FIND_QUIETLY case.

Yes, I think the change still makes sense.  You can rebase on 'master'
and drop the revert/revert-revert sequence to merge to 'next' again.

-Brad

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [cmake-developers] [PATCH] [Module] FindPNG: Add Env Hint via PNG_ROOT

2014-06-27 Thread Brad King
On 06/27/2014 11:04 AM, Huebl, Axel wrote:
 This patch provides users the optional hint via the environment
 variable PNG_ROOT.
 This comes very useful when libpng is not installed in a default
 location and/or if several versions are installed in parallel.

Typically it is not necessary to have a dedicated per-package root
directory setting like this.  Users can set CMAKE_PREFIX_PATH to
their custom prefixes and they will be searched first for all
packages.  See documentation here:

 http://www.cmake.org/cmake/help/v3.0/command/find_library.html
 http://www.cmake.org/cmake/help/v3.0/command/find_path.html

-Brad

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [cmake-developers] [PATCH] [Module] FindPNG: Add Env Hint via PNG_ROOT

2014-06-27 Thread Huebl, Axel
CMAKE_PREFIX_PATH is indeed an option, too.

The main intension of the patch is to align the package with the
standard functionality of other modules (Boost, MPI, HDF5 and similar).

Axel

On 27.06.2014 18:17, Brad King wrote:
 On 06/27/2014 11:04 AM, Huebl, Axel wrote:
 This patch provides users the optional hint via the environment
 variable PNG_ROOT.
 This comes very useful when libpng is not installed in a default
 location and/or if several versions are installed in parallel.
 
 Typically it is not necessary to have a dedicated per-package root
 directory setting like this.  Users can set CMAKE_PREFIX_PATH to
 their custom prefixes and they will be searched first for all
 packages.  See documentation here:
 
  http://www.cmake.org/cmake/help/v3.0/command/find_library.html
  http://www.cmake.org/cmake/help/v3.0/command/find_path.html
 
 -Brad



smime.p7s
Description: S/MIME Cryptographic Signature
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers

Re: [cmake-developers] [PATCH] [Module] FindPNG: Add Env Hint via PNG_ROOT

2014-06-27 Thread Brad King
On 06/27/2014 12:37 PM, Huebl, Axel wrote:
 CMAKE_PREFIX_PATH is indeed an option, too.
 
 The main intension of the patch is to align the package with the
 standard functionality of other modules (Boost, MPI, HDF5 and similar).

Very few modules provide _ROOT variables, and those that do have them
only for historical reasons AFAIK.

-Brad

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [cmake-developers] [PATCH] [Module] FindPNG: Add Env Hint via PNG_ROOT

2014-06-27 Thread Huebl, Axel
Oh you are right, even only 80 out of 297 modules respond to grep _ROOT

I guess I was just spoiled by them.

Thanks for the feedback and congrats on the 3.0 release!

Axel

On 27.06.2014 19:10, Brad King wrote:
 On 06/27/2014 12:37 PM, Huebl, Axel wrote:
 CMAKE_PREFIX_PATH is indeed an option, too.

 The main intension of the patch is to align the package with the
 standard functionality of other modules (Boost, MPI, HDF5 and similar).
 
 Very few modules provide _ROOT variables, and those that do have them
 only for historical reasons AFAIK.
 
 -Brad
 
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


[cmake-developers] [PATCH 3/3] Ninja: Skip generating empty phony rules

2014-06-27 Thread Adam Strzelecki
Ninja generator ensures that all custom commands being target dependencies are
run before other sources compilation. However in case there are no such
dependencies it does currently generate empty phony rules which clutter build
graph.

This change make Ninja generator produce this rules only when necessary.
---
 Source/cmNinjaTargetGenerator.cxx | 30 +-
 Source/cmNinjaTargetGenerator.h   |  3 ++-
 2 files changed, 19 insertions(+), 14 deletions(-)

diff --git a/Source/cmNinjaTargetGenerator.cxx 
b/Source/cmNinjaTargetGenerator.cxx
index 24689fb..57789ee 100644
--- a/Source/cmNinjaTargetGenerator.cxx
+++ b/Source/cmNinjaTargetGenerator.cxx
@@ -542,22 +542,24 @@ cmNinjaTargetGenerator
std::back_inserter(orderOnlyDeps), MapToNinjaPath());
 }
 
-  cmNinjaDeps orderOnlyTarget;
-  orderOnlyTarget.push_back(this-OrderDependsTargetForTarget());
-  this-GetGlobalGenerator()-WritePhonyBuild(this-GetBuildFileStream(),
-  Order-only phony target for 
-+ this-GetTargetName(),
-  orderOnlyTarget,
-  cmNinjaDeps(),
-  cmNinjaDeps(),
-  orderOnlyDeps);
-
+  if (!orderOnlyDeps.empty())
+{
+cmNinjaDeps orderOnlyTarget;
+orderOnlyTarget.push_back(this-OrderDependsTargetForTarget());
+this-GetGlobalGenerator()-WritePhonyBuild(this-GetBuildFileStream(),
+Order-only phony target for 
+  + this-GetTargetName(),
+orderOnlyTarget,
+cmNinjaDeps(),
+cmNinjaDeps(),
+orderOnlyDeps);
+}
   std::vectorcmSourceFile const* objectSources;
   this-GeneratorTarget-GetObjectSources(objectSources, config);
   for(std::vectorcmSourceFile const*::const_iterator
 si = objectSources.begin(); si != objectSources.end(); ++si)
 {
-this-WriteObjectBuildStatement(*si);
+this-WriteObjectBuildStatement(*si, !orderOnlyDeps.empty());
 }
   std::string def = this-GeneratorTarget-GetModuleDefinitionFile(config);
   if(!def.empty())
@@ -570,7 +572,8 @@ cmNinjaTargetGenerator
 
 void
 cmNinjaTargetGenerator
-::WriteObjectBuildStatement(cmSourceFile const* source)
+::WriteObjectBuildStatement(
+  cmSourceFile const* source, bool writeOrderDependsTargetForTarget)
 {
   std::string comment;
   const std::string language = source-GetLanguage();
@@ -599,7 +602,8 @@ cmNinjaTargetGenerator
   }
 
   cmNinjaDeps orderOnlyDeps;
-  orderOnlyDeps.push_back(this-OrderDependsTargetForTarget());
+  if (writeOrderDependsTargetForTarget)
+orderOnlyDeps.push_back(this-OrderDependsTargetForTarget());
 
   // If the source file is GENERATED and does not have a custom command
   // (either attached to this source file or another one), assume that one of
diff --git a/Source/cmNinjaTargetGenerator.h b/Source/cmNinjaTargetGenerator.h
index 94c420f..1a0c206 100644
--- a/Source/cmNinjaTargetGenerator.h
+++ b/Source/cmNinjaTargetGenerator.h
@@ -114,7 +114,8 @@ protected:
   void WriteLanguageRules(const std::string language);
   void WriteCompileRule(const std::string language);
   void WriteObjectBuildStatements();
-  void WriteObjectBuildStatement(cmSourceFile const* source);
+  void WriteObjectBuildStatement(cmSourceFile const* source,
+ bool writeOrderDependsTargetForTarget = true);
   void WriteCustomCommandBuildStatement(cmCustomCommand *cc);
 
   cmNinjaDeps GetObjects() const
-- 
1.9.3 (Apple Git-50)

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


[cmake-developers] [PATCH 2/3] Ninja: Don't limit custom cmd side-effects to build folder (#14972)

2014-06-27 Thread Adam Strzelecki
Actually custom command can write wherever it wants to, such as temporary
folder or source folder, possibly violating rules that only build folder should
be affected. Therefore we should consider custom command dependency at any path
as possible side effect adding phony rule.
---
 Source/cmGlobalNinjaGenerator.cxx | 22 ++
 1 file changed, 6 insertions(+), 16 deletions(-)

diff --git a/Source/cmGlobalNinjaGenerator.cxx 
b/Source/cmGlobalNinjaGenerator.cxx
index eb01654..09ee128 100644
--- a/Source/cmGlobalNinjaGenerator.cxx
+++ b/Source/cmGlobalNinjaGenerator.cxx
@@ -1033,27 +1033,17 @@ void 
cmGlobalNinjaGenerator::WriteUnknownExplicitDependencies(std::ostream os)
   std::back_inserter(unkownExplicitDepends));
 
 
-  std::string const rootBuildDirectory =
-  this-GetCMakeInstance()-GetHomeOutputDirectory();
   for (std::vectorstd::string::const_iterator
i = unkownExplicitDepends.begin();
i != unkownExplicitDepends.end();
++i)
 {
-//verify the file is in the build directory
-std::string const absDepPath = cmSystemTools::CollapseFullPath(
- i-c_str(), rootBuildDirectory.c_str());
-bool const inBuildDir = cmSystemTools::IsSubDirectory(absDepPath.c_str(),
-  rootBuildDirectory.c_str());
-if(inBuildDir)
-  {
-  cmNinjaDeps deps(1,*i);
-  this-WritePhonyBuild(os,
-,
-deps,
-deps);
-  }
-   }
+cmNinjaDeps deps(1,*i);
+this-WritePhonyBuild(os,
+  ,
+  deps,
+  deps);
+}
 }
 
 void cmGlobalNinjaGenerator::WriteBuiltinTargets(std::ostream os)
-- 
1.9.3 (Apple Git-50)

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


[cmake-developers] Broken progress output with make -jXX (aka parallel make)

2014-06-27 Thread Adam Strzelecki
Excuse me if it was discussed already, reported, etc. Even it doesn't affect me 
anyway since I use Ninja, but some of my colleagues still use Make and do 
parallel builds and fancy output is produced: (now some HTML format ;P)

[  5%] [ 15%] [ 21%] [ 26%] [ 26%] Building CXX object 
CMakeFiles/2d_xy_reconstruction.dir/src/2d_xy/reconstruction_cmd.cpp.o
[ 31%] Building CXX object 
CMakeFiles/2d_strip_phantom.dir/src/util/cmdline_hooks.cpp.o
Building CXX object CMakeFiles/2d_strip_phantom.dir/src/util/png_writer.cpp.o
Building CXX object 
CMakeFiles/2d_xy_reconstruction.dir/src/util/png_writer.cpp.o
Building CXX object 
CMakeFiles/2d_strip_phantom.dir/src/2d_strip/phantom_cmd.cpp.o
[ 42%] [ 42%] [ 47%] Building CXX object 
CMakeFiles/2d_xy_reconstruction.dir/src/util/cmdline_hooks.cpp.o
Building NVCC (Device) object 
CMakeFiles/cuda_compile.dir/src/2d_strip/cuda/./cuda_compile_generated_reconstruction_strip_gpu.cu.o
Building NVCC (Device) object 
CMakeFiles/cuda_compile.dir/src/2d_xy/cuda/./cuda_compile_generated_phantom_kernel.cu.o
Building NVCC (Device) object 
CMakeFiles/cuda_compile.dir/src/2d_xy/cuda/./cuda_compile_generated_matrix_kernel.cu.o
Linking CXX executable 2d_xy_reconstruction

As you probably notice percentage is decoupled by rest of status line.

This is probably due percentage output is done by separate echo command and it 
gets mixed with other threads. I presume emitting percents and rest of status 
line would fix that.

--Adam-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers

Re: [CMake] Add libraries to end of compilation line ...

2014-06-27 Thread Michael Burns via CMake

  
  
Hello.

That is a good idea, Hendrik. I'll look into that.

Angeliki, we set the CMAKE_CXX_FLAGS... and CMAKE_C_FLAGS... values
with various options. I simply added the -static and
-static-libstdc++ to those. Again, I'm trying to do this without
having to modify all of the existing scripts and without adding
"special requirements" when new scripts are added in the future.

Thank you both for your insights.

Mike


On 6/26/2014 11:49 AM, Angeliki
  Chrysochou wrote:


  Hi,
  This is a good idea Hendrik! Mike, how are you
creating your static libraries? You don't need to at the
"-static" option yourself...you could tell cmake you want a
static library using add_library(${YOUR_LIB} STATIC ${SOURCES}).
  Cheers,
Angeliki
  On Jun 26, 2014 8:12 PM, "Hendrik
Sattler" p...@hendrik-sattler.de
wrote:

  Hi,

you can also override the target_link_libraries function
with your own in the top-level lists file and call the
original one from within that function. This way you only
have to edit one file.

HS


On 26. Juni 2014 18:14:36 MESZ,
  Michael Burns via CMake cmake@cmake.org
  wrote:
  
Hello, Angeliki.

Yes, you are correct. I want to link against the static libraries (.a)
rather than the shared objects (.so). I know it "shouldn't" make a
difference, but it is. Adding the "-static" option to the gcc command

line causes the link failures to happen. Without that option, everything
builds just fine.

Ideally, I would just like to set some property that caused these common
libraries to be appended to the end of the compilation line as defined

in link.txt. Unfortunately, I haven't seen anything like that.

Your suggestion seems to be the only option. That means I will need to
update nearly 180 CMake scripts. And, we'll need to make sure any new

scripts contain this value for every instance of TARGET_LINK_LIBRARIES
statement. A painful process!

Thank you for your response, Angeliki.

Mike


On 6/26/2014 1:16 AM, Angeliki Chrysochou wrote:

 Hi Michael,

 I think what matters is the correctly set dependencies for your build
 to succeed (target_link_libraries). By "statically link" you mean you

 link against static libraries that were before shared objects, right?
 This should, to my knowledge, not have any influence to how you use
 target_link_libraries.

 My assumption would be that maybe these static libraries are not set

 as linking dependencies to all necessary target_link_libraries.

 If I understood your problem correctly, if you want to have a set of
 libraries that are linking dependencies to all your libraries, you
 could use the following approach: set a variable (list or simple) in

 your top level CMakeLists.txt file, and then by default add it to all
 target_link_libraries. You could modify these "global
dependencies" or
 even have this variable empty with no problems.

 For example your top level CMakeLists.txt could contain:

 set(GLOBAL_LIBRARIES "LibA.so" "LibB.so")


 and then have this in the CMakeLists.txt files of the rest of your
 libraries:

 target_link_libraries(${YOUR_LIB}
 ${GLOBAL_LIBRARIES}
 ...
 )

 Maybe there is some better practice out there for this, if so, I would

 also be interested to know :)

 Cheers!
 Angeliki


 On Wed, Jun 25, 2014 at 7:46 PM, Michael Burns via CMake
 cmake@cmake.org mailto:cmake@cmake.org wrote:


 Hello, all.

 I work on a cross-platform project that has many libraries and several
 applications. CMake on Linux naturally adds the TARGET_LINK_LIBRARIES
 specified in the libraries after those specified in
the
 TARGET_LINK_LIBRARIES for the application. However, there are several
 common system libraries, for example pthread, that are used by many of
 the libraries and most of the applications.


 The current scripts only have the common system libraries
 specified in a
 few scattered places. And, it works. However, we're trying to
 change to
 statically link these libraries and the links are failing with

 "undefined reference" errors. When I manually modify link.txt to
 add the
 various system libraries to the end of the compilation line, it works.
 So, rather than going through all of the scripts (of which there are

 many), I would like to be able to list them so they are added to
 the end
 of every link.

 Is there a way to identify libraries in such a way that they are added
 to the end of the compilation line rather than
having to add those
 libraries to every library and application that requires them?

 Thanks!

 Mike
  

  

  

  

-- 

Powered by www.kitware.com

Please keep 

Re: [CMake] Add libraries to end of compilation line ...

2014-06-27 Thread Kornel Benko
Am Donnerstag, 26. Juni 2014 um 20:12:12, schrieb Hendrik Sattler 
p...@hendrik-sattler.de
 Hi,
 
 you can also override the target_link_libraries function with your own in the 
 top-level lists file and call the original one from within that function. 
 This way you only have to edit one file.


Nice idea, but how to call the original function from within? If I do that, I 
get a recursion
into the overriding function.

Kornel

signature.asc
Description: This is a digitally signed message part.
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

Re: [CMake] Preventing search for libraries in random prefixes

2014-06-27 Thread Angeliki Chrysochou
Hi Mojca,

From what I know cmake will look for libraries in the directories specified
in link_directories(${LIBRARY_DIRS}) and for headers in the directories
specified in include_directories(${INCLUDE_DIRS}) and the property
INCLUDE_DIRECTORIES.

http://www.cmake.org/cmake/help/v2.8.8/cmake.html#command:link_directories

http://www.cmake.org/cmake/help/v2.8.8/cmake.html#command:include_directories

Cheers!
Angeliki



On Thu, Jun 26, 2014 at 10:56 PM, Mojca Miklavec mo...@macports.org wrote:

 Hi,

 In our package manager where it is of crucial importance to link
 against the proper library we often end up with hardcoding lots and
 lots of options, like:

 -DOPENGL_INCLUDE_DIR=${prefix}/include \
 -DX11_ICE_INCLUDE_PATH=${prefix}/include \
 -DX11_SM_INCLUDE_PATH=${prefix}/include \
 -DX11_X11_INCLUDE_PATH=${prefix}/include \
 -DX11_Xext_INCLUDE_PATH=${prefix}/include \
 -DX11_Xft_INCLUDE_PATH=${prefix}/include \
 -DX11_Xpm_INCLUDE_PATH=${prefix}/include \
 -DX11_ICE_LIB=${prefix}/lib/libICE.dylib \
 -DX11_SM_LIB=${prefix}/lib/libSM.dylib \
 -DX11_X11_LIB=${prefix}/lib/libX11.dylib \
 -DX11_Xext_LIB=${prefix}/lib/libXext.dylib \
 -DX11_Xft_LIB=${prefix}/lib/libXft.dylib \
 -DX11_Xpm_LIB=${prefix}/lib/libXpm.dylib \
 -DOPENGL_gl_LIBRARY=${prefix}/lib/libGL.dylib \

 With autotools that usually boiled down to just:
 --with-x=${prefix}

 My question: is there any way to tell CMake the following?

 Please don't search for any libraries or headers from /sw or /usr/X11
 or /opt/local or anything, I really really want you to search for the
 libraries in /my/special/prefix and only there.

 A while back a user asked for removing /sw from CMake FindFoo
 modules because that caused him problems. But I would like to
 understand the general policy about this.

 See:
 https://trac.macports.org/ticket/41817

 I like that fact that CMake eventually offers more flexibility, but it
 makes it a bit painful to ensure that exactly the right libraries are
 used. I'm sure that I'm missing something though, so I would like to
 understand how to handle this properly.

 Thank you,
 Mojca
 --

 Powered by www.kitware.com

 Please keep messages on-topic and check the CMake FAQ at:
 http://www.cmake.org/Wiki/CMake_FAQ

 Kitware offers various services to support the CMake community. For more
 information on each offering, please visit:

 CMake Support: http://cmake.org/cmake/help/support.html
 CMake Consulting: http://cmake.org/cmake/help/consulting.html
 CMake Training Courses: http://cmake.org/cmake/help/training.html

 Visit other Kitware open-source projects at
 http://www.kitware.com/opensource/opensource.html

 Follow this link to subscribe/unsubscribe:
 http://public.kitware.com/mailman/listinfo/cmake

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

Re: [CMake] Preventing search for libraries in random prefixes

2014-06-27 Thread Angeliki Chrysochou
Hi Mojca,

I don't know if removing these paths would break your build maybe...I'm
sorry I couldn't help.

Angeliki




On Fri, Jun 27, 2014 at 11:26 AM, Mojca Miklavec mo...@macports.org wrote:

 On Fri, Jun 27, 2014 at 10:42 AM, Angeliki Chrysochou wrote:
  Hi Mojca,
 
  From what I know cmake will look for libraries in the directories
 specified
  in link_directories(${LIBRARY_DIRS}) and for headers in the directories
  specified in include_directories(${INCLUDE_DIRS}) and the property
  INCLUDE_DIRECTORIES.
 
 
 http://www.cmake.org/cmake/help/v2.8.8/cmake.html#command:link_directories
 
 
 http://www.cmake.org/cmake/help/v2.8.8/cmake.html#command:include_directories

 The problem is that some files like FindGTK2.cmake explicitly specify
 additional (undesired) search paths, for example:

 find_path(GTK2_${_var}_INCLUDE_DIR ${_hdr}
 PATHS
 ${_gtk2_arch_dir}
 /usr/local/lib64
 /usr/local/lib
 /usr/lib64
 /usr/lib
 /opt/gnome/include
 /opt/gnome/lib
 /opt/openwin/include
 /usr/openwin/lib
 /sw/include
 /sw/lib
 /opt/local/include
 /opt/local/lib
 /usr/pkg/lib
 /usr/pkg/include/glib
 $ENV{GTKMM_BASEPATH}/include
 $ENV{GTKMM_BASEPATH}/lib
 [HKEY_CURRENT_USER\\SOFTWARE\\gtkmm\\2.4;Path]/include
 [HKEY_CURRENT_USER\\SOFTWARE\\gtkmm\\2.4;Path]/lib
 [HKEY_LOCAL_MACHINE\\SOFTWARE\\gtkmm\\2.4;Path]/include
 [HKEY_LOCAL_MACHINE\\SOFTWARE\\gtkmm\\2.4;Path]/lib
 PATH_SUFFIXES
 ${_suffixes}
 )

 I would like to get rid of those.

 Mojca

  On Thu, Jun 26, 2014 at 10:56 PM, Mojca Miklavec mo...@macports.org
 wrote:
 
  Hi,
 
  In our package manager where it is of crucial importance to link
  against the proper library we often end up with hardcoding lots and
  lots of options, like:
 
  -DOPENGL_INCLUDE_DIR=${prefix}/include \
  -DX11_ICE_INCLUDE_PATH=${prefix}/include \
  -DX11_SM_INCLUDE_PATH=${prefix}/include \
  -DX11_X11_INCLUDE_PATH=${prefix}/include \
  -DX11_Xext_INCLUDE_PATH=${prefix}/include \
  -DX11_Xft_INCLUDE_PATH=${prefix}/include \
  -DX11_Xpm_INCLUDE_PATH=${prefix}/include \
  -DX11_ICE_LIB=${prefix}/lib/libICE.dylib \
  -DX11_SM_LIB=${prefix}/lib/libSM.dylib \
  -DX11_X11_LIB=${prefix}/lib/libX11.dylib \
  -DX11_Xext_LIB=${prefix}/lib/libXext.dylib \
  -DX11_Xft_LIB=${prefix}/lib/libXft.dylib \
  -DX11_Xpm_LIB=${prefix}/lib/libXpm.dylib \
  -DOPENGL_gl_LIBRARY=${prefix}/lib/libGL.dylib \
 
  With autotools that usually boiled down to just:
  --with-x=${prefix}
 
  My question: is there any way to tell CMake the following?
 
  Please don't search for any libraries or headers from /sw or /usr/X11
  or /opt/local or anything, I really really want you to search for the
  libraries in /my/special/prefix and only there.
 
  A while back a user asked for removing /sw from CMake FindFoo
  modules because that caused him problems. But I would like to
  understand the general policy about this.
 
  See:
  https://trac.macports.org/ticket/41817
 
  I like that fact that CMake eventually offers more flexibility, but it
  makes it a bit painful to ensure that exactly the right libraries are
  used. I'm sure that I'm missing something though, so I would like to
  understand how to handle this properly.
 
  Thank you,
  Mojca

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

Re: [CMake] Preventing search for libraries in random prefixes

2014-06-27 Thread Mojca Miklavec
On Fri, Jun 27, 2014 at 11:28 AM, Angeliki Chrysochou wrote:
 Hi Mojca,

 I don't know if removing these paths would break your build maybe...I'm
 sorry I couldn't help.

It wouldn't break my build, but it seems weird and unnatural to do
such extensive patching to CMake's Find modules.

Mojca
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


Re: [CMake] Preventing search for libraries in random prefixes

2014-06-27 Thread Ben Morgan
Hi Mojca,

On 27 June 2014 10:26, Mojca Miklavec mo...@macports.org wrote:

 On Fri, Jun 27, 2014 at 10:42 AM, Angeliki Chrysochou wrote:
  Hi Mojca,
 
  From what I know cmake will look for libraries in the directories
 specified
  in link_directories(${LIBRARY_DIRS}) and for headers in the directories
  specified in include_directories(${INCLUDE_DIRS}) and the property
  INCLUDE_DIRECTORIES.
 
 
 http://www.cmake.org/cmake/help/v2.8.8/cmake.html#command:link_directories
 
 
 http://www.cmake.org/cmake/help/v2.8.8/cmake.html#command:include_directories

 The problem is that some files like FindGTK2.cmake explicitly specify
 additional (undesired) search paths, for example:

 find_path(GTK2_${_var}_INCLUDE_DIR ${_hdr}
 PATHS
 ${_gtk2_arch_dir}
 /usr/local/lib64
 /usr/local/lib
 /usr/lib64
 /usr/lib
 /opt/gnome/include
 /opt/gnome/lib
 /opt/openwin/include
 /usr/openwin/lib
 /sw/include
 /sw/lib
 /opt/local/include
 /opt/local/lib
 /usr/pkg/lib
 /usr/pkg/include/glib
 $ENV{GTKMM_BASEPATH}/include
 $ENV{GTKMM_BASEPATH}/lib
 [HKEY_CURRENT_USER\\SOFTWARE\\gtkmm\\2.4;Path]/include
 [HKEY_CURRENT_USER\\SOFTWARE\\gtkmm\\2.4;Path]/lib
 [HKEY_LOCAL_MACHINE\\SOFTWARE\\gtkmm\\2.4;Path]/include
 [HKEY_LOCAL_MACHINE\\SOFTWARE\\gtkmm\\2.4;Path]/lib
 PATH_SUFFIXES
 ${_suffixes}
 )

 I would like to get rid of those.


I don't think you can get rid of them as such as I'm not sure if a global
setting of things
like NO_DEFAULT_PATH and so on exist (do they?). I think you can bias the
search though
by using variables like CMAKE_PREFIX_PATH - these should be first in the
search path
according to the docs for find_path and find_library.

I've used this to point CMake at my own toolkits and it's worked quite well.

Ben.






 Mojca

  On Thu, Jun 26, 2014 at 10:56 PM, Mojca Miklavec mo...@macports.org
 wrote:
 
  Hi,
 
  In our package manager where it is of crucial importance to link
  against the proper library we often end up with hardcoding lots and
  lots of options, like:
 
  -DOPENGL_INCLUDE_DIR=${prefix}/include \
  -DX11_ICE_INCLUDE_PATH=${prefix}/include \
  -DX11_SM_INCLUDE_PATH=${prefix}/include \
  -DX11_X11_INCLUDE_PATH=${prefix}/include \
  -DX11_Xext_INCLUDE_PATH=${prefix}/include \
  -DX11_Xft_INCLUDE_PATH=${prefix}/include \
  -DX11_Xpm_INCLUDE_PATH=${prefix}/include \
  -DX11_ICE_LIB=${prefix}/lib/libICE.dylib \
  -DX11_SM_LIB=${prefix}/lib/libSM.dylib \
  -DX11_X11_LIB=${prefix}/lib/libX11.dylib \
  -DX11_Xext_LIB=${prefix}/lib/libXext.dylib \
  -DX11_Xft_LIB=${prefix}/lib/libXft.dylib \
  -DX11_Xpm_LIB=${prefix}/lib/libXpm.dylib \
  -DOPENGL_gl_LIBRARY=${prefix}/lib/libGL.dylib \
 
  With autotools that usually boiled down to just:
  --with-x=${prefix}
 
  My question: is there any way to tell CMake the following?
 
  Please don't search for any libraries or headers from /sw or /usr/X11
  or /opt/local or anything, I really really want you to search for the
  libraries in /my/special/prefix and only there.
 
  A while back a user asked for removing /sw from CMake FindFoo
  modules because that caused him problems. But I would like to
  understand the general policy about this.
 
  See:
  https://trac.macports.org/ticket/41817
 
  I like that fact that CMake eventually offers more flexibility, but it
  makes it a bit painful to ensure that exactly the right libraries are
  used. I'm sure that I'm missing something though, so I would like to
  understand how to handle this properly.
 
  Thank you,
  Mojca
 --

 Powered by www.kitware.com

 Please keep messages on-topic and check the CMake FAQ at:
 http://www.cmake.org/Wiki/CMake_FAQ

 Kitware offers various services to support the CMake community. For more
 information on each offering, please visit:

 CMake Support: http://cmake.org/cmake/help/support.html
 CMake Consulting: http://cmake.org/cmake/help/consulting.html
 CMake Training Courses: http://cmake.org/cmake/help/training.html

 Visit other Kitware open-source projects at
 http://www.kitware.com/opensource/opensource.html

 Follow this link to subscribe/unsubscribe:
 http://public.kitware.com/mailman/listinfo/cmake

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:

Re: [CMake] Add libraries to end of compilation line ...

2014-06-27 Thread Hendrik Sattler
Hi,

IIRC the old function is preserved as the same name with an underscore as 
prefix...

Regards,

HS

On 27. Juni 2014 10:23:07 MESZ, Kornel Benko kor...@lyx.org wrote:
Am Donnerstag, 26. Juni 2014 um 20:12:12, schrieb Hendrik Sattler
p...@hendrik-sattler.de
 Hi,
 
 you can also override the target_link_libraries function with your
own in the top-level lists file and call the original one from within
that function. This way you only have to edit one file.


Nice idea, but how to call the original function from within? If I do
that, I get a recursion
into the overriding function.

   Kornel



-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at:
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For
more information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

-- 
Diese Nachricht wurde von meinem Android-Mobiltelefon mit K-9 Mail gesendet.-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

[CMake] fixup_bundle and bundle install names

2014-06-27 Thread Mikael Sundell
fixup_bundle can't resolve dynamic libraries with non-absolute
install_names. I'm linking my macosx cmake project against an sdk inside an
application bundle, the sdk libraries are relative to the application
bundle configuration. It seems as if the fixup_bundle uses the install name
even if it's not absolute instead of the actual file path, typical output:

-- fixup_bundle: preparing...
-- warning: embedded item does not exist
'/git/studio/QuickComp/install/quickcomp.app/Contents/MacOS/liblpcore.dylib'
-- 
warning: cannot resolve item '@executable_path/liblpcore.dylib'

  possible problems:
need more directories?
need to use InstallRequiredSystemLibraries?
run in install tree instead of build tree?

warning: target '@executable_path/liblpcore.dylib' is not absolute...
warning: target '@executable_path/liblpcore.dylib' does not exist...
/usr/bin/otool: can't open file: @executable_path/liblpcore.dylib (No such
file or directory)

@executable_path/liblpcore.dylib is the install name of the bundle
dynamic library.

Is there a work-around or an override that can be used?

Mikael
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

[CMake] adding dependencies to a target

2014-06-27 Thread abid rahman
Hello,

I am adding a new target using add_library(target source1 source2). Then
add the dependencies of targets by target_link_libraries(target deps)

But this source2 is generated by another python script based on
dependencies of target. ie, I need to specify the dependencies of target
before the add_library() line. But unfortunately target is not created
before add_library() line. So how can I specify the dependencies of target
before add_library() or is there any other workaround?

(Sorry, if question is not clear, I am new to cmake. Let me know if I need
to explain more)

Abid K.
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

[Cmake-commits] CMake branch, next, updated. v3.0.0-3960-g4138163

2014-06-27 Thread Nils Gladitz
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  41381633529bd60a265e640a5ac339eb75e75958 (commit)
   via  6112fd1a088c44b052d30eb05116517804467593 (commit)
  from  b071fb689142fbbfc8aa1502d7e1059aa3bea4c7 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=41381633529bd60a265e640a5ac339eb75e75958
commit 41381633529bd60a265e640a5ac339eb75e75958
Merge: b071fb6 6112fd1
Author: Nils Gladitz nilsglad...@gmail.com
AuthorDate: Fri Jun 27 03:53:34 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 03:53:34 2014 -0400

Merge topic 'FindQt4-ignore-qt5' into next

6112fd1a Revert FindQt4: Don't further process qmake if it does not belong 
to Qt4


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=6112fd1a088c44b052d30eb05116517804467593
commit 6112fd1a088c44b052d30eb05116517804467593
Author: Nils Gladitz nilsglad...@gmail.com
AuthorDate: Fri Jun 27 09:52:00 2014 +0200
Commit: Nils Gladitz nilsglad...@gmail.com
CommitDate: Fri Jun 27 09:52:00 2014 +0200

Revert FindQt4: Don't further process qmake if it does not belong to Qt4

This reverts commit a279641a5dbd234b45775757c1e025aa03a3281f.
The diagnostic issue was already fixed by Clinton in
83934757c942672d8bea79f11e51a184b168a212.

diff --git a/Modules/FindQt4.cmake b/Modules/FindQt4.cmake
index c942c1c..c930042 100644
--- a/Modules/FindQt4.cmake
+++ b/Modules/FindQt4.cmake
@@ -518,8 +518,7 @@ set(QT4_INSTALLED_VERSION_TOO_OLD FALSE)
 set(_QT4_QMAKE_NAMES qmake qmake4 qmake-qt4 qmake-mac)
 _qt4_find_qmake(${_QT4_QMAKE_NAMES} QT_QMAKE_EXECUTABLE QTVERSION)
 
-if (QT_QMAKE_EXECUTABLE AND
-  QTVERSION VERSION_GREATER 3 AND QTVERSION VERSION_LESS 5)
+if (QT_QMAKE_EXECUTABLE AND QTVERSION)
 
   if (Qt5Core_FOUND)
 # Qt5CoreConfig sets QT_MOC_EXECUTABLE as a non-cache variable to the Qt 5

---

Summary of changes:
 Modules/FindQt4.cmake |3 +--
 1 file changed, 1 insertion(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.0.0-3962-g9e150f5

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  9e150f53f1241ea9910b9b0a504825fe657a9d84 (commit)
   via  115811dcbd9253cd662b2cd9c15c844d07aa5679 (commit)
  from  41381633529bd60a265e640a5ac339eb75e75958 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=9e150f53f1241ea9910b9b0a504825fe657a9d84
commit 9e150f53f1241ea9910b9b0a504825fe657a9d84
Merge: 4138163 115811d
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 09:25:57 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 09:25:57 2014 -0400

Merge topic 'FindJPEG-new-windows-name' into next

115811dc FindJPEG: Add alternative name 'libjpeg'


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=115811dcbd9253cd662b2cd9c15c844d07aa5679
commit 115811dcbd9253cd662b2cd9c15c844d07aa5679
Author: Sebastian Elsner sebast...@risefx.com
AuthorDate: Thu Jun 26 21:12:29 2014 +0200
Commit: Brad King brad.k...@kitware.com
CommitDate: Fri Jun 27 09:26:05 2014 -0400

FindJPEG: Add alternative name 'libjpeg'

Newer versions of jpeglib build the .lib file on Windows with a
different name by default.  Its now called libjpeg.lib instead of
jpeg.lib.

diff --git a/Modules/FindJPEG.cmake b/Modules/FindJPEG.cmake
index 90e4485..86bb6e5 100644
--- a/Modules/FindJPEG.cmake
+++ b/Modules/FindJPEG.cmake
@@ -33,7 +33,7 @@
 
 find_path(JPEG_INCLUDE_DIR jpeglib.h)
 
-set(JPEG_NAMES ${JPEG_NAMES} jpeg)
+set(JPEG_NAMES ${JPEG_NAMES} jpeg libjpeg)
 find_library(JPEG_LIBRARY NAMES ${JPEG_NAMES} )
 
 # handle the QUIETLY and REQUIRED arguments and set JPEG_FOUND to TRUE if

---

Summary of changes:
 Modules/FindJPEG.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.0.0-3964-g5af7447

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  5af7447ab8cc51e888d3676594c01110beb518c0 (commit)
   via  4671f3ab7dc65186484ce31dff5e810aa2792145 (commit)
  from  9e150f53f1241ea9910b9b0a504825fe657a9d84 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5af7447ab8cc51e888d3676594c01110beb518c0
commit 5af7447ab8cc51e888d3676594c01110beb518c0
Merge: 9e150f5 4671f3a
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 09:33:35 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 09:33:35 2014 -0400

Merge topic 'FindOpenMP-intel-qopenmp' into next

4671f3ab FindOpenMP: ICC 15 deprecates -openmp, use -qopenmp


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4671f3ab7dc65186484ce31dff5e810aa2792145
commit 4671f3ab7dc65186484ce31dff5e810aa2792145
Author: Adam Strzelecki o...@java.pl
AuthorDate: Thu Jun 26 15:29:04 2014 +0200
Commit: Brad King brad.k...@kitware.com
CommitDate: Fri Jun 27 09:30:51 2014 -0400

FindOpenMP: ICC 15 deprecates -openmp, use -qopenmp

Intel Composer XE 2015 Beta 2 deprecates all options starting with -o
for sake of compatibility with other compilers expecting anything goes
after -o... is output file name.

diff --git a/Modules/FindOpenMP.cmake b/Modules/FindOpenMP.cmake
index 30972ae..935a0ca 100644
--- a/Modules/FindOpenMP.cmake
+++ b/Modules/FindOpenMP.cmake
@@ -68,8 +68,11 @@ function(_OPENMP_FLAG_CANDIDATES LANG)
   set(OMP_FLAG_HP +Oopenmp)
   if(WIN32)
 set(OMP_FLAG_Intel -Qopenmp)
-  else()
+  elseif(CMAKE_${LANG}_COMPILER_ID STREQUAL Intel AND
+ ${CMAKE_${LANG}_COMPILER_VERSION} VERSION_LESS 15.0.0.20140528)
 set(OMP_FLAG_Intel -openmp)
+  else()
+set(OMP_FLAG_Intel -qopenmp)
   endif()
   set(OMP_FLAG_MIPSpro -mp)
   set(OMP_FLAG_MSVC /openmp)

---

Summary of changes:
 Modules/FindOpenMP.cmake |5 -
 1 file changed, 4 insertions(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.0.0-1231-g3138da6

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  3138da6e675102af8bd81e8715abc7a57806377f (commit)
   via  d19b64d671e9f1e706218bd0acc6a727e7114158 (commit)
   via  c9568de52c4e11c04a9f758ea9ecc1e72ea7cbfb (commit)
   via  ec7cf7ea1311adaf6eb8dd1ab5c2aa8e3745339e (commit)
   via  abebcd235c94e05a20003430981a1b46b0fb7f95 (commit)
   via  464567a577555659610b2a26f9c1733d672583de (commit)
   via  f701b0b7f7eb4a7cd6fe96f285835b03604fb477 (commit)
   via  f0a0196250de349e97fe579165f7a9b580ed63e8 (commit)
   via  67815894cabcba32b6afbf3438dc45a00f1a7406 (commit)
  from  feb44093bc1a5b503ef26fb633a58baeec144d0a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=3138da6e675102af8bd81e8715abc7a57806377f
commit 3138da6e675102af8bd81e8715abc7a57806377f
Merge: feb4409 d19b64d
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 09:42:42 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 09:42:42 2014 -0400

Merge topic 'install-messages'

d19b64d6 install(DIRECTORY): Add MESSAGE_NEVER option to avoid output 
(#13761)
c9568de5 install: Add CMAKE_INSTALL_MESSAGE variable (#13761)
ec7cf7ea install: Thread message level setting through internal API
abebcd23 file(INSTALL): Add undocumented options to control output verbosity
464567a5 file(INSTALL): Report existing DIRECTORY as Up-to-date
f701b0b7 file(INSTALL): Do not pre-create DESTINATION for DIRECTORY
f0a01962 cmInstallTargetGenerator: Drop default constructor arguments
67815894 Help: Add install() command document section headers


---

Summary of changes:
 Help/command/file.rst  |3 +-
 Help/command/install.rst   |   30 +--
 Help/manual/cmake-variables.7.rst  |1 +
 Help/release/dev/install-messages.rst  |8 ++
 Help/variable/CMAKE_INSTALL_MESSAGE.rst|   30 +++
 Source/cmFileCommand.cxx   |   87 
 Source/cmInstallCommand.cxx|   31 ++-
 Source/cmInstallDirectoryGenerator.cxx |4 +-
 Source/cmInstallDirectoryGenerator.h   |1 +
 Source/cmInstallExportGenerator.cxx|3 +-
 Source/cmInstallExportGenerator.h  |1 +
 Source/cmInstallFilesCommand.cxx   |4 +-
 Source/cmInstallFilesGenerator.cxx |3 +-
 Source/cmInstallFilesGenerator.h   |1 +
 Source/cmInstallGenerator.cxx  |   38 -
 Source/cmInstallGenerator.h|   16 +++-
 Source/cmInstallProgramsCommand.cxx|4 +-
 Source/cmInstallScriptGenerator.cxx|2 +-
 Source/cmInstallTargetGenerator.cxx|6 +-
 Source/cmInstallTargetGenerator.h  |   10 +--
 Source/cmLocalGenerator.cxx|   23 +-
 Tests/RunCMake/file/INSTALL-DIRECTORY-stdout.txt   |8 ++
 Tests/RunCMake/file/INSTALL-DIRECTORY.cmake|   10 +++
 .../INSTALL-MESSAGE-bad-result.txt}|0
 Tests/RunCMake/file/INSTALL-MESSAGE-bad-stderr.txt |   32 +++
 Tests/RunCMake/file/INSTALL-MESSAGE-bad.cmake  |6 ++
 Tests/RunCMake/file/RunCMakeTest.cmake |2 +
 .../hello.f = Tests/RunCMake/file/dir/empty.txt   |0
 .../install/DIRECTORY-MESSAGE_NEVER-check.cmake|   13 +++
 .../RunCMake/install/DIRECTORY-MESSAGE_NEVER.cmake |3 +
 .../DIRECTORY-PATTERN-MESSAGE_NEVER-result.txt}|0
 .../DIRECTORY-PATTERN-MESSAGE_NEVER-stderr.txt |4 +
 .../install/DIRECTORY-PATTERN-MESSAGE_NEVER.cmake  |1 +
 .../RunCMake/install/DIRECTORY-message-check.cmake |   28 +++
 .../install/DIRECTORY-message-lazy-check.cmake |   24 ++
 .../RunCMake/install/DIRECTORY-message-lazy.cmake  |3 +
 Tests/RunCMake/install/DIRECTORY-message.cmake |3 +
 Tests/RunCMake/install/RunCMakeTest.cmake  |4 +
 .../RunCMake/install/dir/empty.txt |0
 39 files changed, 405 insertions(+), 42 deletions(-)
 create mode 100644 Help/release/dev/install-messages.rst
 create mode 100644 Help/variable/CMAKE_INSTALL_MESSAGE.rst
 create mode 100644 Tests/RunCMake/file/INSTALL-DIRECTORY-stdout.txt
 create mode 100644 Tests/RunCMake/file/INSTALL-DIRECTORY.cmake
 copy Tests/RunCMake/{CMP0004/CMP0004-NEW-result.txt = 
file/INSTALL-MESSAGE-bad-result.txt} (100%)
 create mode 100644 

[Cmake-commits] CMake branch, master, updated. v3.0.0-1250-g2196cae

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  2196cae4ecae60711b6ef6ad6def9b7b988b4eb7 (commit)
   via  e932ac9cadc2e87401be5c1fe57cfae1a80c8000 (commit)
  from  a87e8056acf733c4ee3cbd87bc21966918bd8659 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=2196cae4ecae60711b6ef6ad6def9b7b988b4eb7
commit 2196cae4ecae60711b6ef6ad6def9b7b988b4eb7
Merge: a87e805 e932ac9
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 09:42:54 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 09:42:54 2014 -0400

Merge topic 'UseSWIG-fix-noproxy-check'

e932ac9c UseSWIG: Fix check for noproxy flag (#14990)


---

Summary of changes:
 Modules/UseSWIG.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.0.0-1248-ga87e805

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  a87e8056acf733c4ee3cbd87bc21966918bd8659 (commit)
   via  6650b0fa43ef55e8bad9188c584f40d515f38bd6 (commit)
   via  bc1517579d897678ad734e82201be42d4e2a7cba (commit)
  from  798d7626a01296bf6af6f8c2e1d1457faf665543 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a87e8056acf733c4ee3cbd87bc21966918bd8659
commit a87e8056acf733c4ee3cbd87bc21966918bd8659
Merge: 798d762 6650b0f
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 09:42:50 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 09:42:50 2014 -0400

Merge topic 'bootstrap-cmake-locations'

6650b0fa bootstrap: Fix make test and make package targets (#14989)
bc151757 bootstrap: Clarify name of configured source directory


---

Summary of changes:
 Source/cmSystemTools.cxx |7 ++-
 bootstrap|9 ++---
 2 files changed, 12 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.0.0-3973-g270ee47

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  270ee4751f4615a6af2e499eb384e0616b8e1813 (commit)
   via  2196cae4ecae60711b6ef6ad6def9b7b988b4eb7 (commit)
   via  a87e8056acf733c4ee3cbd87bc21966918bd8659 (commit)
   via  798d7626a01296bf6af6f8c2e1d1457faf665543 (commit)
   via  55bba3a197d5727478aaac4c0e93801dcd0e8f1d (commit)
   via  4fc453c420064b0584b668ce42965fb31dd9ed09 (commit)
   via  3138da6e675102af8bd81e8715abc7a57806377f (commit)
   via  feb44093bc1a5b503ef26fb633a58baeec144d0a (commit)
   via  ed7f3b81a83869cad82f18313af30d62d2d2ea49 (commit)
  from  5af7447ab8cc51e888d3676594c01110beb518c0 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=270ee4751f4615a6af2e499eb384e0616b8e1813
commit 270ee4751f4615a6af2e499eb384e0616b8e1813
Merge: 5af7447 2196cae
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 09:44:29 2014 -0400
Commit: Brad King brad.k...@kitware.com
CommitDate: Fri Jun 27 09:44:29 2014 -0400

Merge branch 'master' into next


---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.0.0-1245-g798d762

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  798d7626a01296bf6af6f8c2e1d1457faf665543 (commit)
   via  a73373a8c8ca261398b605572c6e23936496056d (commit)
  from  55bba3a197d5727478aaac4c0e93801dcd0e8f1d (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=798d7626a01296bf6af6f8c2e1d1457faf665543
commit 798d7626a01296bf6af6f8c2e1d1457faf665543
Merge: 55bba3a a73373a
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 09:42:48 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 09:42:48 2014 -0400

Merge topic 'CTestTestTimeout-increase'

a73373a8 CTestTestTimeout: increase the timeout for all platforms


---

Summary of changes:
 Tests/CTestTestTimeout/CMakeLists.txt |7 ++-
 1 file changed, 2 insertions(+), 5 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.0.0-1243-g55bba3a

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  55bba3a197d5727478aaac4c0e93801dcd0e8f1d (commit)
   via  24637979962012ae170f7848ad69e896f8d3f67c (commit)
   via  7812d2a912ca596d3db9d28a9291e83a55ffe75c (commit)
   via  f48d8bd6f6bee4a24a3c716fc744f8dcdff7b399 (commit)
   via  7b0834e9bbe614670552036b14c7556a3c76c9a9 (commit)
   via  b8651d970d06325b9ad5166295e3bbc25052a8fd (commit)
   via  0192be51819f8765131fc059b3ee210011eb7b80 (commit)
   via  6ead631bf9ec6da8eeca5fb39e5eba80e5022f15 (commit)
   via  b030a7f1ca89620ad4b51569c991a7c0b8aa05c2 (commit)
   via  1001490df27f3ab93f8a37a6f6c3b33aa26d22e2 (commit)
  from  4fc453c420064b0584b668ce42965fb31dd9ed09 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=55bba3a197d5727478aaac4c0e93801dcd0e8f1d
commit 55bba3a197d5727478aaac4c0e93801dcd0e8f1d
Merge: 4fc453c 2463797
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 09:42:46 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 09:42:46 2014 -0400

Merge topic 'refactor-link-internals'

24637979 cmTarget: Refactor ComputeLinkImplementation
7812d2a9 cmTarget: Pre-indent a block in ComputeLinkImplementation
f48d8bd6 cmTarget: Shorten a long line in ComputeLinkImplementation
7b0834e9 cmTarget: Refactor internal LinkImplementation map
b8651d97 cmTarget: Remove unnecessary 'mutable' markup
0192be51 cmTarget: De-duplicate link interface evaluation for $LINK_ONLY
6ead631b cmTarget: Teach GetLinkInterfaceLibraries to support $LINK_ONLY
b030a7f1 cmTarget: De-duplicate link interface genex code for $LINK_ONLY
1001490d cmTarget: Teach ExpandLinkItems how to support $LINK_ONLY


---

Summary of changes:
 Source/cmTarget.cxx |  319 +--
 Source/cmTarget.h   |9 +-
 2 files changed, 160 insertions(+), 168 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.0.0-1233-g4fc453c

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  4fc453c420064b0584b668ce42965fb31dd9ed09 (commit)
   via  3bae343f62e050da78476811234e1f8a055f5d04 (commit)
  from  3138da6e675102af8bd81e8715abc7a57806377f (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=4fc453c420064b0584b668ce42965fb31dd9ed09
commit 4fc453c420064b0584b668ce42965fb31dd9ed09
Merge: 3138da6 3bae343
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 09:42:44 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 09:42:44 2014 -0400

Merge topic 'stringapi-crash-cleanup'

3bae343f cmCPackGenerator: Avoid crash on undefined CMAKE_MAKE_PROGRAM


---

Summary of changes:
 Source/CPack/cmCPackGenerator.cxx |4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.0.0-1253-gbf5fc1d

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  bf5fc1d5829e7995c0941996b4a515cbd46d4e4e (commit)
   via  d08da54576e66336dd6c13219b5fe7cd1a361ac6 (commit)
   via  a2d65c66b1c89f26849b805da340059589d7a87d (commit)
  from  2196cae4ecae60711b6ef6ad6def9b7b988b4eb7 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, release, updated. v3.0.0-11-gd08da54

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, release has been updated
   via  d08da54576e66336dd6c13219b5fe7cd1a361ac6 (commit)
   via  e932ac9cadc2e87401be5c1fe57cfae1a80c8000 (commit)
   via  a2d65c66b1c89f26849b805da340059589d7a87d (commit)
   via  6650b0fa43ef55e8bad9188c584f40d515f38bd6 (commit)
   via  bc1517579d897678ad734e82201be42d4e2a7cba (commit)
  from  3ec3b8a926a921113d6232e3b9aaf20acfd746fb (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
---

Summary of changes:
 Modules/UseSWIG.cmake|2 +-
 Source/cmSystemTools.cxx |7 ++-
 bootstrap|9 ++---
 3 files changed, 13 insertions(+), 5 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.0.0-3977-g24b83a7

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  24b83a78f42168cc5ba687935c32b3abe6150e93 (commit)
   via  bf5fc1d5829e7995c0941996b4a515cbd46d4e4e (commit)
   via  d08da54576e66336dd6c13219b5fe7cd1a361ac6 (commit)
   via  a2d65c66b1c89f26849b805da340059589d7a87d (commit)
  from  270ee4751f4615a6af2e499eb384e0616b8e1813 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=24b83a78f42168cc5ba687935c32b3abe6150e93
commit 24b83a78f42168cc5ba687935c32b3abe6150e93
Merge: 270ee47 bf5fc1d
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 09:45:16 2014 -0400
Commit: Brad King brad.k...@kitware.com
CommitDate: Fri Jun 27 09:45:16 2014 -0400

Merge branch 'master' into next


---

Summary of changes:


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.0.0-3986-g587d0e0

2014-06-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  587d0e08aaee2a3ddd562dbe4b3cd7a95a130c4f (commit)
   via  f0e298ad661a82f8368c7adea14e912d36ae8886 (commit)
  from  a24a57450cf24200b54387ea6695ae44be6093af (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=587d0e08aaee2a3ddd562dbe4b3cd7a95a130c4f
commit 587d0e08aaee2a3ddd562dbe4b3cd7a95a130c4f
Merge: a24a574 f0e298a
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 10:25:16 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 10:25:16 2014 -0400

Merge topic 'vs14-generator' into next

f0e298ad Help: Add notes for topic 'vs14-generator'


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=f0e298ad661a82f8368c7adea14e912d36ae8886
commit f0e298ad661a82f8368c7adea14e912d36ae8886
Author: Brad King brad.k...@kitware.com
AuthorDate: Fri Jun 27 10:19:27 2014 -0400
Commit: Brad King brad.k...@kitware.com
CommitDate: Fri Jun 27 10:19:27 2014 -0400

Help: Add notes for topic 'vs14-generator'

diff --git a/Help/release/dev/vs14-generator.rst 
b/Help/release/dev/vs14-generator.rst
new file mode 100644
index 000..0bda236
--- /dev/null
+++ b/Help/release/dev/vs14-generator.rst
@@ -0,0 +1,4 @@
+vs14-generator
+--
+
+* A :generator:`Visual Studio 14` generator was added.

---

Summary of changes:
 Help/release/dev/vs14-generator.rst |4 
 1 file changed, 4 insertions(+)
 create mode 100644 Help/release/dev/vs14-generator.rst


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, next, updated. v3.0.0-3995-g53ece55

2014-06-27 Thread Robert Maynard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, next has been updated
   via  53ece55f0bf137573118543409595c8b5bd4cf48 (commit)
   via  d0d2fdd4b55fa96c6964e908dc6361ec471456e7 (commit)
  from  b32b4cb4ec17e56f201dc92aea049ec2a062 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=53ece55f0bf137573118543409595c8b5bd4cf48
commit 53ece55f0bf137573118543409595c8b5bd4cf48
Merge: b32b4cb d0d2fdd
Author: Robert Maynard robert.mayn...@kitware.com
AuthorDate: Fri Jun 27 16:58:50 2014 -0400
Commit: CMake Topic Stage kwro...@kitware.com
CommitDate: Fri Jun 27 16:58:50 2014 -0400

Merge topic 'cuda_osx_clang' into next

d0d2fdd4 FindCUDA: Fix OSX Clang  no C language enabled


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=d0d2fdd4b55fa96c6964e908dc6361ec471456e7
commit d0d2fdd4b55fa96c6964e908dc6361ec471456e7
Author: Adam Strzelecki o...@java.pl
AuthorDate: Thu Jun 12 19:46:50 2014 +0200
Commit: Robert Maynard robert.mayn...@kitware.com
CommitDate: Fri Jun 27 16:58:05 2014 -0400

FindCUDA: Fix OSX Clang  no C language enabled

When setting default CUDA_HOST_COMPILER we must dereference 
CMAKE_C_COMPILER,
i.e. /usr/bin/clang should be used instead /usr/bin/cc which is symlink.
Otherwise CUDA thinks it is GCC and issues -dumpspecs which is unknown 
option
to Clang.

Also in case neither CMAKE_C_COMPILER is defined (project does not use C
language) nor CUDA_HOST_COMPILER is specified manually we should skip -ccbin
and let nvcc use its own default C compiler.

diff --git a/Modules/FindCUDA.cmake b/Modules/FindCUDA.cmake
index d9809ad..9e6e2a3 100644
--- a/Modules/FindCUDA.cmake
+++ b/Modules/FindCUDA.cmake
@@ -452,7 +452,14 @@ set(CUDA_NVCC_FLAGS  CACHE STRING Semi-colon delimit 
multiple arguments.)
 if(CMAKE_GENERATOR MATCHES Visual Studio)
   set(CUDA_HOST_COMPILER $(VCInstallDir)bin CACHE FILEPATH Host side 
compiler used by NVCC)
 else()
-  set(CUDA_HOST_COMPILER ${CMAKE_C_COMPILER} CACHE FILEPATH Host side 
compiler used by NVCC)
+  # Using cc which is symlink to clang may let NVCC think it is GCC and issue
+  # unhandled -dumpspecs option to clang.
+  if(DEFINED CMAKE_C_COMPILER AND NOT DEFINED CUDA_HOST_COMPILER)
+get_filename_component(c_compiler_realpath ${CMAKE_C_COMPILER} REALPATH)
+  else()
+set(c_compiler_realpath )
+  endif()
+  set(CUDA_HOST_COMPILER ${c_compiler_realpath} CACHE FILEPATH Host side 
compiler used by NVCC)
 endif()
 
 # Propagate the host flags to the host compiler via -Xcompiler
@@ -1422,7 +1429,7 @@ function(CUDA_LINK_SEPARABLE_COMPILATION_OBJECTS 
output_file cuda_target options
 # If -ccbin, --compiler-bindir has been specified, don't do anything.  
Otherwise add it here.
 list( FIND nvcc_flags -ccbin ccbin_found0 )
 list( FIND nvcc_flags --compiler-bindir ccbin_found1 )
-if( ccbin_found0 LESS 0 AND ccbin_found1 LESS 0 )
+if( ccbin_found0 LESS 0 AND ccbin_found1 LESS 0 AND CUDA_HOST_COMPILER )
   list(APPEND nvcc_flags -ccbin \${CUDA_HOST_COMPILER}\)
 endif()
 # Create a list of flags specified by CUDA_NVCC_FLAGS_${CONFIG}
diff --git a/Modules/FindCUDA/run_nvcc.cmake b/Modules/FindCUDA/run_nvcc.cmake
index f0aac84..58e0d31 100644
--- a/Modules/FindCUDA/run_nvcc.cmake
+++ b/Modules/FindCUDA/run_nvcc.cmake
@@ -62,7 +62,7 @@ set(cmake_dependency_file @cmake_dependency_file@) # path
 set(CUDA_make2cmake @CUDA_make2cmake@) # path
 set(CUDA_parse_cubin @CUDA_parse_cubin@) # path
 set(build_cubin @build_cubin@) # bool
-set(CUDA_HOST_COMPILER @CUDA_HOST_COMPILER@) # bool
+set(CUDA_HOST_COMPILER @CUDA_HOST_COMPILER@) # path
 # We won't actually use these variables for now, but we need to set this, in
 # order to force this file to be run again if it changes.
 set(generated_file_path @generated_file_path@) # path
@@ -106,7 +106,7 @@ list(APPEND CUDA_NVCC_FLAGS 
${CUDA_NVCC_FLAGS_${build_configuration}})
 # Any -ccbin existing in CUDA_NVCC_FLAGS gets highest priority
 list( FIND CUDA_NVCC_FLAGS -ccbin ccbin_found0 )
 list( FIND CUDA_NVCC_FLAGS --compiler-bindir ccbin_found1 )
-if( ccbin_found0 LESS 0 AND ccbin_found1 LESS 0 )
+if( ccbin_found0 LESS 0 AND ccbin_found1 LESS 0 AND CUDA_HOST_COMPILER )
   if (CUDA_HOST_COMPILER STREQUAL $(VCInstallDir)bin AND DEFINED CCBIN)
 set(CCBIN -ccbin ${CCBIN})
   else()

---

Summary of changes:
 Modules/FindCUDA.cmake  |   11 +--
 Modules/FindCUDA/run_nvcc.cmake |4 ++--
 2 files changed, 11 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake

[Cmake-commits] CMake branch, master, updated. v3.0.0-1254-gc7cf28a

2014-06-27 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project CMake.

The branch, master has been updated
   via  c7cf28ae351599e3f50fa22bae4817f6aee4406c (commit)
  from  bf5fc1d5829e7995c0941996b4a515cbd46d4e4e (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=c7cf28ae351599e3f50fa22bae4817f6aee4406c
commit c7cf28ae351599e3f50fa22bae4817f6aee4406c
Author: Kitware Robot kwro...@kitware.com
AuthorDate: Sat Jun 28 00:01:08 2014 -0400
Commit: Kitware Robot kwro...@kitware.com
CommitDate: Sat Jun 28 00:01:08 2014 -0400

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index 9a7a6f2..8bd6e1a 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -1,5 +1,5 @@
 # CMake version number components.
 set(CMake_VERSION_MAJOR 3)
 set(CMake_VERSION_MINOR 0)
-set(CMake_VERSION_PATCH 20140627)
+set(CMake_VERSION_PATCH 20140628)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
1.9.3 (Apple Git-50)

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


[cmake-developers] [PATCH 1/3] Ninja: Consider only custom commands deps as side-effects (#14972)

2014-06-27 Thread Adam Strzelecki
Previously all explicit dependencies inside build folder were considered as
possible build command side-effects and phony rules were produced for them in
case they don't exist yet starting build. This however incorrect since regular
compile inputs need to exist otherwise cmake will fail. Moreover the exception
for sources having GENERATED property that can be missing is already handled by
WriteAssumedSourceDependencies.

This fixes unwanted phony rules for all regular source files when doing
in-source build, causing Ninja not complain when such files gets missing, i.e.
during development. Also this reduces number of rules in ninja.build.

Now only custom command dependencies are considered as possible side-effects.
---
 Source/cmGlobalNinjaGenerator.cxx | 22 --
 Source/cmGlobalNinjaGenerator.h   |  9 +
 2 files changed, 17 insertions(+), 14 deletions(-)

diff --git a/Source/cmGlobalNinjaGenerator.cxx 
b/Source/cmGlobalNinjaGenerator.cxx
index 0facfeb..eb01654 100644
--- a/Source/cmGlobalNinjaGenerator.cxx
+++ b/Source/cmGlobalNinjaGenerator.cxx
@@ -151,11 +151,6 @@ void cmGlobalNinjaGenerator::WriteBuild(std::ostream os,
   ++i)
 {
 arguments +=   + EncodeIdent(EncodePath(*i), os);
-
-//we need to track every dependency that comes in, since we are trying
-//to find dependencies that are side effects of build commands
-//
-this-CombinedBuildExplicitDependencies.insert( EncodePath(*i) );
 }
 
   // Write implicit dependencies.
@@ -280,6 +275,13 @@ cmGlobalNinjaGenerator::WriteCustomCommandBuild(const 
std::string command,
cmNinjaDeps(),
orderOnly,
vars);
+
+  //we need to track every dependency that comes in, since we are trying
+  //to find dependencies that are side effects of build commands
+  for(cmNinjaDeps::const_iterator i = deps.begin(); i != deps.end(); ++i)
+{
+this-CombinedCustomCommandExplicitDependencies.insert( EncodePath(*i) );
+}
 }
 
 void
@@ -1015,17 +1017,17 @@ void 
cmGlobalNinjaGenerator::WriteUnknownExplicitDependencies(std::ostream os)
   //to keep this data around
   this-CombinedBuildOutputs.clear();
 
   //now we difference with CombinedBuildExplicitDependencies to find
   //the list of items we know nothing about.
   //We have encoded all the paths in CombinedBuildExplicitDependencies
   //and knownDependencies so no matter if unix or windows paths they
   //should all match now.
 
   std::vectorstd::string unkownExplicitDepends;
-  this-CombinedBuildExplicitDependencies.erase(all);
+  this-CombinedCustomCommandExplicitDependencies.erase(all);
 
-  std::set_difference(this-CombinedBuildExplicitDependencies.begin(),
-  this-CombinedBuildExplicitDependencies.end(),
+  std::set_difference(this-CombinedCustomCommandExplicitDependencies.begin(),
+  this-CombinedCustomCommandExplicitDependencies.end(),
   knownDependencies.begin(),
   knownDependencies.end(),
   std::back_inserter(unkownExplicitDepends));
@@ -1015,17 +1017,17 @@ void 
   this-CombinedBuildOutputs.clear();
 
-  //now we difference with CombinedBuildExplicitDependencies to find
+  //now we difference with CombinedCustomCommandExplicitDependencies to find
   //the list of items we know nothing about.
@@ -1015,17 +1017,17 @@ void 
   //the list of items we know nothing about.
-  //We have encoded all the paths in CombinedBuildExplicitDependencies
+  //We have encoded all the paths in CombinedCustomCommandExplicitDependencies
   //and knownDependencies so no matter if unix or windows paths they
   //should all match now.
diff --git a/Source/cmGlobalNinjaGenerator.h b/Source/cmGlobalNinjaGenerator.h
index f2643af..ff110d7 100644
--- a/Source/cmGlobalNinjaGenerator.h
+++ b/Source/cmGlobalNinjaGenerator.h
@@ -363,10 +363,11 @@ private:
   /// The set of custom command outputs we have seen.
   std::setstd::string CustomCommandOutputs;
 
-  //The combined explicit dependencies of all build commands that the global
-  //generator has issued. When combined with CombinedBuildOutputs it allows
-  //us to detect the set of explicit dependencies that have
-  std::setstd::string CombinedBuildExplicitDependencies;
+  /// The combined explicit dependencies of custom build commands
+  std::setstd::string CombinedCustomCommandExplicitDependencies;
+
+  /// When combined with CombinedCustomCommandExplicitDependencies it allows
+  /// us to detect the set of explicit dependencies that have
   std::setstd::string CombinedBuildOutputs;
 
   /// The mapping from source file to assumed dependencies.
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits